Struct ZwpTabletV1
pub struct ZwpTabletV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
graphics tablet device
The wp_tablet interface represents one graphics tablet device. The tablet interface itself does not generate events; all events are generated by wp_tablet_tool objects when in proximity above a tablet.
A tablet has a number of static characteristics, e.g. device name and pid/vid. These capabilities are sent in an event sequence after the wp_tablet_seat.tablet_added event. This initial event sequence is terminated by a wp_tablet.done event.
See also the Event enum for this interface.
Implementations
impl ZwpTabletV1
impl ZwpTabletV1
pub fn destroy(&self)
pub fn destroy(&self)
destroy the tablet object
This destroys the client’s resource for this tablet object.